@@ -21,6 +21,13 @@ KEYS_MAPPING = {
 
 
 def get_char() -> str:
+    """
+    Read a keypress and return the resulting character as a string.
+
+    Returns:
+        char: the pressed key or the key description (e.g. "home")
+    """
+    try:
     ch: str = getwch()
     if ch == WIN_ESC:  # When reading arrow/insert/del key, the first call returnx 0xe0
         ch = getwch()  # The second call returns the key code
